@@ -99,7 +99,7 @@ class Controller:
     def shorteningService(self):
         url = self.url
         short_url, long_url = url, ''
-        shortening_services = str(pathlib.Path(__file__).parent.absolute()) + r'/data/shortening_services.txt'
+        shortening_services = str(pathlib.Path(__file__).parent.absolute()) + r'\data\shortening_services.txt'
         test_read = open(shortening_services, 'r')
         
         havingIP = Controller.havingIPAddress(self)
@@ -184,7 +184,7 @@ class Controller:
             if(len(issued_by.split(" "))>1):
                 CA = issued_by.split(" ")[0] + " " + issued_by.split(" ")[1] 
             
-            ssl_list = str(pathlib.Path(__file__).parent.absolute()) + r'/data/ssl_list.txt'
+            ssl_list = str(pathlib.Path(__file__).parent.absolute()) + r'\data\ssl_list.txt'
             SSL_read = open(ssl_list,'r')
             
             if((issued_by.split()[0] or CA)in SSL_read.read()):
@@ -193,7 +193,7 @@ class Controller:
                 return 1
     
     def domainRegistration(self):
-        edu_domains = str(pathlib.Path(__file__).parent.absolute()) + r'/data/edu_domains.txt'
+        edu_domains = str(pathlib.Path(__file__).parent.absolute()) + r'\data\edu_domains.txt'
         test_read = open(edu_domains, 'r')
         parts = self.parts
         domain_name = parts.netloc
@@ -678,11 +678,14 @@ class Controller:
         
         OS = str(platform.system()).lower()
         if('windows' in OS):
-            driver = webdriver.Chrome(executable_path=r'.\dependencies\windows\chromedriver.exe', options=chrome_options)
+            chromedriver_windows = str(pathlib.Path(__file__).parent.absolute()) + r'\dependencies\windows\chromedriver.exe'
+            driver = webdriver.Chrome(executable_path=chromedriver_windows, options=chrome_options)
         elif('linux' in OS):
-            driver = webdriver.Chrome(executable_path=r'.\dependencies\linux\chromedriver', options=chrome_options)
+            chromedriver_linux = str(pathlib.Path(__file__).parent.absolute()) + r'\dependencies\linux\chromedriver'
+            driver = webdriver.Chrome(executable_path=chromedriver_linux, options=chrome_options)
         elif('darwin' in OS):
-            driver = webdriver.Chrome(executable_path=r'.\dependencies\macOS\chromedriver', options=chrome_options)
+            chromedriver_macOS = str(pathlib.Path(__file__).parent.absolute()) = r'\dependencies\macOS\chromedriver'
+            driver = webdriver.Chrome(executable_path=chromedriver_macOS, options=chrome_options)
         else:
             driver = None
         if(driver):
